<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sk">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikácia proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation> IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Voliteľné</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložiť</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid port</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Odpojiť</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Vymazať</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložiť</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Pripájanie</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Odpojiť</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Káblové Pripojenie %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE pripojenie %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Nová VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN typ</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportovať</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikácia proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detaily siete</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systém Proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Drôtová sieť</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrôtová sieť</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-child_page>Airplane Mode</extra-child_page>
        <extra-contents_path>/network/Airplane Mode</extra-contents_path>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Pridať sieťové spojenie</translation>
        <extra-child_page>Wired Network</extra-child_page>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Pripojiť sa k skrytej sieti</translation>
        <extra-child_page>Wireless Network</extra-child_page>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-child_page_hide>DSL</extra-child_page_hide>
        <extra-contents_path>/network/DSL</extra-contents_path>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Vytvoriť PPPoE pripojenie</translation>
        <extra-child_page>DSL</extra-child_page>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN</extra-contents_path>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Vytvoriť VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importovať VPN</translation>
        <extra-child_page>VPN</extra-child_page>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurácia URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation> IP adresa</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
        <extra-child_page>Application Proxy</extra-child_page>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
        <extra-child_page>Personal Hotspot</extra-child_page>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhranie</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation> Primárna DNS</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rýchlosť</translation>
        <extra-child_page>Network Details</extra-child_page>
        <extra-contents_path>/network/Network Details</extra-contents_path>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Device MAC Addr</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Cloned MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Vlastné MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Hlavné</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Hlavné</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Pridať nastavenie</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation> IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatické</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovať</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation> IP adresa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Používa sa iba v zodpovedajúcich zdrojoch</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metóda</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metóda</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatické</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorovať</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Detaily siete</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Systém Proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Aplikácia proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Detaily siete</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Sieť</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázané</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatické</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Služba</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmietnuť EAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmietnuť PAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmietnuť CHAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmietnuť MSCHAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmietnuť MSCHAPv2 Autentizáciu</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Žiadna BSD Data kompresia</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Žiadna Deflate Data kompresia</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Žiadna TCP Header kompresia</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Žiadna Protocol Field kompresia</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Žiadna Addres/Control kompresia</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Odoslať PPP Echo pakety</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Použiť MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Vytvoriť PPPoE pripojenie</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Systém Proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Uložiť</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ručné</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatické</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Voliteľné</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Required</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorovať nasledujúcu konfiguráciu proxy pre vyššie uvedených hostiteľov a domény</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurácia URL</translation>
        <extra-child_page>System Proxy</extra-child_page>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Bezpečnosť</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tunelované TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Chránené EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázané</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonymné</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Overené</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Obe</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automaticky</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Verzia 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Verzia 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP autentizácia</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identita</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privátny kľúč</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikát</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Užívateľský certifikát</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anonymné ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisioning</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC súbor</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Inner autentizácia</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP verzia</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Private PWD</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpečnosť</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kľúč</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Požadovaná bezpečnosť</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpečnosť</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Overenie</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kľúč</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Pokročilé VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Vlastný port brány</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Port brány</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Vlastný Renegotiation interval</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Renegotiation interval</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Použiť LZO data kompresiu</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Použiť TCP spojenie</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Použiť TAP zariadenie</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Vlastné Tunnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Vlastná UDP veľkosť fragmentu</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP Veľkosť fragmentu</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restrict Tunnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Náhodné vzdialené hosty</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Pokročilé VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (predvolené)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Bezpečné (predvolené)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Slabé</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Keď je dostupné (predvolené)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T vždy</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázané</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Group 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Group 2 (predvolené)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Group 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Server (predvolené)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Group 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Doména</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzia</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Kódovanie</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT Traversal Mode</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH Group</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Forward Secrecy</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Lokálny port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Zakázať Dead Peer detekciu</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Povoliť IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Group Name</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Group ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmy fázy 1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmy fázy 2</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikát</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Povoliť Cisco Secure Desktop Trojan</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD Skript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Užívateľský certifikát</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privátny kľúč</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Použiť FSID pre Key Passphrase</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certifikáty (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certifikáty s heslom (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statický kľúč</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uložené</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pýtať sa</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nie je požadované</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ autentizácie</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikát</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Užívateľský certifikát</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privátny kľúč</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Private PWD</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Upraviť Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Vzdialená IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Lokálna IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Všetky dostupné (predvolené)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation> 40-bit (menej bezpečné)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation> 128-bit (najbezpečnejšie)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Odmietnuť EAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Odmietnuť PAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Odmietnuť CHAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Odmietnuť MSCHAP Autentizáciu</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Odmietnuť MSCHAPv2 Autentizáciu</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Žiadna BSD Data kompresia</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Žiadna Deflate Data kompresia</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Žiadna TCP Header kompresia</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Žiadna Protocol Field kompresia</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Žiadna Addres/Control kompresia</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Odoslať PPP Echo pakety</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Použiť MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpečnosť</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Stateful MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN status</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Vytvoriť VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importovať VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importovať chybu</translation>
    </message>
    <message>
        <source>File error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nie je požadované</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Typ proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Skúsiť znovu, ak dôjde k zlyhaniu</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA súbor</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN bezpečnosť</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Šifra</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC autentizácia</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uložené</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pýtať sa</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nie je požadované</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation> NT doména</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Server IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privátny kľúč</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Agent</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Pre-Shared Key</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA certifikát</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Typ autentizácie</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Užívateľský certifikát</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Požiadať o vnútornú IP adresu</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Vynútiť UDP zapúzdrenie</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Použiť IP kompresiu</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS autentizácia</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Server</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Subject Match</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Typ vzdialeného certifikátu</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Súbor s kľúčom</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Upraviť Key Direction</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Key Direction</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved</source>
        <translation>Uložené</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Pýtať sa</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nie je požadované</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Požadované</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Meno používateľa</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Group Name</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Group Pwd</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Použiť Hybrid Authentication</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA súbor</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Najprv pripojte sieťový kábel</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Pridať sieťové spojenie</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Výber nastavenia</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Zatvoriť hotspot</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Pripojiť sa k skrytej sieti</translation>
        <extra-child_page>WirelessPage</extra-child_page>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Device MAC Addr</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Vlastné MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanál</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Pásmo</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Rozhranie</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Maska</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Brána</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation> Primárna DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefix</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Rýchlosť</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Zariadenie zakázané</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Pripojené, ale bez prístupu na internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Nepripojené</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Sieťový kábel odpojený</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Pripájanie</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Overujem</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Získavanie IP adresy</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Pripojené</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Odpojené</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Zlyhanie</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Drôtová sieť</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Káblová sieť %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Bezdrôtová sieť</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Bezdrôtová sieť %1</translation>
    </message>
</context>
</TS>